#include <iostream>
#include "knt_reader.h"
#include <opencv2/opencv.hpp>

int main()
{
	try {
		std::string knt_file("./Face.knt");
		KntReader reader(knt_file);
		int c_start = reader.get_color_start_idx();
		int c_end = reader.get_color_end_idx();
		int d_start = reader.get_depth_start_idx();
		int d_end = reader.get_depth_end_idx();
		std::cout << "c_start = " << c_start << ", c_end = " << c_end << std::endl;
		std::cout << "d_start = " << d_start << ", d_end = " << d_end << std::endl;

		std::string color_dir("./color");
		std::string depth_dir("./depth");
		// save color frames
		for (int frame_idx = c_start; frame_idx < c_end; ++frame_idx) {
			char color_file[256] = { 0 };
			sprintf(color_file, "%s/Frame_%03d.png", color_dir.c_str(), frame_idx);
			cv::Mat color_frame = reader.get_color_frame(frame_idx);
			cv::imwrite(color_file, color_frame);
			
			std::cout << "color frame " << frame_idx << " is processed !" << std::endl;
		}

		// save depth frames
		for (int frame_idx = d_start; frame_idx < d_end; ++frame_idx) {
			char depth_file[256] = { 0 };
			sprintf(depth_file, "%s/Frame_%03d.png", depth_dir.c_str(), frame_idx);
			cv::Mat depth_frame = reader.get_depth_frame(frame_idx);
			cv::imwrite(depth_file, depth_frame);

			std::cout << "depth frame = " << frame_idx << " is processed !" << std::endl;
		}

	}
	catch (std::exception &e) {
		std::cerr << e.what() << std::endl;
		return 1;
	}

	return 0;
}